.. Copyright © SixtyFPS GmbH <info@slint.dev>
.. SPDX-License-Identifier: MIT

Widgets
========

.. include:: widgets.md
   :parser: myst_parser.sphinx_

.. toctree::
   :hidden:
   :maxdepth: 4
   :caption: Widgets

   aboutslint.md
   button.md
   checkbox.md
   combobox.md
   gridbox.md
   groupbox.md
   horizontalbox.md
   lineedit.md
   listview.md
   progressindicator.md
   scrollview.md
   slider.md
   spinbox.md
   spinner.md
   standardbutton.md
   standardlistview.md
   standardtableview.md
   switch.md
   tabwidget.md
   textedit.md
   verticalbox.md
